@@ -23,9 +23,9 @@
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QPixmapCache>
+#include <QX11Info>
 #include "applicationadaptor.h"
 #include "screenshotdialog.h"
-#include "preferencesdialog.h"
 #include "mainwindow.h"
 
 using namespace LxImage;
@@ -37,7 +37,7 @@ Application::Application(int& argc, char** argv):
   QApplication(argc, argv),
   libFm(),
   windowCount_(0) {
-  setApplicationVersion(LXIMAGE_VERSION);
+  setApplicationVersion(QStringLiteral(LXIMAGE_VERSION));
 }
 
 bool Application::init(int argc, char** argv) {
@@ -47,26 +47,26 @@ bool Application::init(int argc, char** argv) {
   setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
   // install the translations built-into Qt itself
-  qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+  qtTranslator.load(QStringLiteral("qt_") + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
   installTranslator(&qtTranslator);
 
   // install libfm-qt translator
   installTranslator(libFm.translator());
 
   // install our own tranlations
-  translator.load("lximage-qt_" + QLocale::system().name(), LXIMAGE_DATA_DIR "/translations");
+  translator.load(QStringLiteral("lximage-qt_") + QLocale::system().name(), QStringLiteral(LXIMAGE_DATA_DIR) + QStringLiteral("/translations"));
   installTranslator(&translator);
 
   // initialize dbus
   QDBusConnection dbus = QDBusConnection::sessionBus();
-  if(dbus.registerService(serviceName)) {
+  if(dbus.registerService(QLatin1String(serviceName))) {
     settings_.load(); // load settings
     // we successfully registered the service
     isPrimaryInstance = true;
     setQuitOnLastWindowClosed(false); // do not quit even when there're no windows
 
     new ApplicationAdaptor(this);
-    dbus.registerObject("/Application", this);
+    dbus.registerObject(QStringLiteral("/Application"), this);
 
     connect(this, &Application::aboutToQuit, this, &Application::onAboutToQuit);
 
@@ -89,19 +89,34 @@ bool Application::parseCommandLineArgs() {
   parser.addHelpOption();
   parser.addVersionOption();
 
+  const bool isX11 = QX11Info::isPlatformX11();
+
   QCommandLineOption screenshotOption(
-    QStringList() << "s" << "screenshot",
+    QStringList() << QStringLiteral("s") << QStringLiteral("screenshot"),
     tr("Take a screenshot")
   );
-  parser.addOption(screenshotOption);
+  if(isX11) {
+    parser.addOption(screenshotOption);
+  }
+
+
+  QCommandLineOption screenshotOptionDir(
+    QStringList() << QStringLiteral("d") << QStringLiteral("dirscreenshot"),
+    tr("Take a screenshot and save it to the directory without showing the GUI"), tr("DIR")
+  );
+  if(isX11) {
+    parser.addOption(screenshotOptionDir);
+  }
 
   const QString files = tr("[FILE1, FILE2,...]");
-  parser.addPositionalArgument("files", files, files);
+  parser.addPositionalArgument(QStringLiteral("files"), files, files);
 
   parser.process(*this);
 
   const QStringList args = parser.positionalArguments();
-  const bool screenshotTool = parser.isSet(screenshotOption);
+  bool screenshotTool = false;
+  if(isX11)
+    screenshotTool = parser.isSet(screenshotOption);
 
   QStringList paths;
   for(const QString& arg : args) {
@@ -109,6 +124,15 @@ bool Application::parseCommandLineArgs() {
     paths.push_back(info.absoluteFilePath());
   }
 
+
+  //silent no-gui screenshot
+  if(isX11) {
+    if (parser.isSet(screenshotOptionDir)) {
+        ScreenshotDialog::cmdTopShotToDir(parser.value(screenshotOptionDir));
+        return false;
+    }
+  }
+
   bool keepRunning = false;
   if(isPrimaryInstance) {
     settings_.load();
@@ -116,19 +140,18 @@ bool Application::parseCommandLineArgs() {
     if(screenshotTool) {
       screenshot();
     }
-    else {
-      newWindow(paths);
-    }
+    else
+        newWindow(paths);
   }
   else {
     // we're not the primary instance.
     // call the primary instance via dbus to do operations
     QDBusConnection dbus = QDBusConnection::sessionBus();
-    QDBusInterface iface(serviceName, "/Application", ifaceName, dbus, this);
+    QDBusInterface iface(QLatin1String(serviceName), QStringLiteral("/Application"), QLatin1String(ifaceName), dbus, this);
     if(screenshotTool)
-      iface.call("screenshot");
+      iface.call(QStringLiteral("screenshot"));
     else
-      iface.call("newWindow", paths);
+      iface.call(QStringLiteral("newWindow"), paths);
   }
   return keepRunning;
 }
@@ -136,6 +159,34 @@ bool Application::parseCommandLineArgs() {
 MainWindow* Application::createWindow() {
   LxImage::MainWindow* window;
   window = new LxImage::MainWindow();
+
+  // get default shortcuts from the first window
+  if(defaultShortcuts_.isEmpty()) {
+    const auto actions = window->findChildren<QAction*>();
+    for(const auto& action : actions) {
+      QKeySequence seq = action->shortcut();
+      ShortcutDescription s;
+      s.displayText = action->text().remove QStringLiteral("&"); // without mnemonics
+      s.shortcut = seq;
+      defaultShortcuts_.insert(action->objectName(), s);
+    }
+  }
+
+  // apply custom shortcuts to this window
+  QHash<QString, QString> ca = settings_.customShortcutActions();
+  const auto actions = window->findChildren<QAction*>();
+  for(const auto& action : actions) {
+    const QString objectName = action->objectName();
+    if(ca.contains(objectName)) {
+      auto shortcut = ca.take(objectName);
+      // custom shortcuts are saved in the PortableText format.
+      action->setShortcut(QKeySequence(shortcut, QKeySequence::PortableText));
+    }
+    if(ca.isEmpty()) {
+      break;
+    }
+  }
+
   return window;
 }
 
@@ -169,8 +220,9 @@ void Application::newWindow(QStringList files) {
 void Application::applySettings() {
   const auto windows = topLevelWidgets();
   for(QWidget* window : windows) {
-    if(window->inherits("LxImage::MainWindow"))
+    if(window->inherits("LxImage::MainWindow")) {
       static_cast<MainWindow*>(window)->applySettings();
+    }
   }
 }
 
@@ -180,8 +232,16 @@ void Application::screenshot() {
 }
 
 void Application::editPreferences() {
-  PreferencesDialog* dlg = new PreferencesDialog();
-  dlg->show();
+  // open Preferences dialog only if default shortcuts are known
+  if(defaultShortcuts_.isEmpty()) {
+    return;
+  }
+  if(preferencesDialog_ == nullptr) {
+    preferencesDialog_ = new PreferencesDialog();
+  }
+  preferencesDialog_.data()->show();
+  preferencesDialog_.data()->raise();
+  preferencesDialog_.data()->activateWindow();
 }
 
 void Application::onAboutToQuit() {
