@@ -30,9 +30,11 @@
 #include <QGraphicsSvgItem>
 #include <QPainter>
 #include <QPainterPath>
+#include <QGuiApplication>
 #include <QtMath>
 
 #define CURSOR_HIDE_DELY 3000
+#define GRAY 127
 
 namespace LxImage {
 
@@ -40,13 +42,15 @@ ImageView::ImageView(QWidget* parent):
   QGraphicsView(parent),
   scene_(new GraphicsScene(this)),
   imageItem_(new QGraphicsRectItem()),
+  outlineItem_(new QGraphicsRectItem()),
   gifMovie_(nullptr),
   cacheTimer_(nullptr),
   cursorTimer_(nullptr),
   scaleFactor_(1.0),
   autoZoomFit_(false),
   isSVG(false),
-  currentTool(ToolNone) {
+  currentTool(ToolNone),
+  showOutline_(false) {
 
   setViewportMargins(0, 0, 0, 0);
   setContentsMargins(0, 0, 0, 0);
@@ -57,6 +61,10 @@ ImageView::ImageView(QWidget* parent):
   imageItem_->hide();
   imageItem_->setPen(QPen(Qt::NoPen)); // remove the border
   scene_->addItem(imageItem_);
+
+  outlineItem_->hide();
+  outlineItem_->setPen(QPen(Qt::NoPen));
+  scene_->addItem(outlineItem_);
 }
 
 ImageView::~ImageView() {
@@ -142,7 +150,7 @@ void ImageView::mouseReleaseEvent(QMouseEvent* event) {
       painter.setFont(font);
 
       // Calculate the dimensions of the text
-      QString text = QString("%1").arg(nextNumber++);
+      QString text = QStringLiteral("%1").arg(nextNumber++);
       QRectF textRect = painter.boundingRect(image_.rect(), 0, text);
       textRect.moveTo(endPoint);
 
@@ -201,7 +209,8 @@ void ImageView::zoomFit() {
   if(!image_.isNull()) {
     // if the image is smaller than our view, use its original size
     // instead of scaling it up.
-    if(image_.width() <= width() && image_.height() <= height()) {
+    if(static_cast<int>(image_.width() / qApp->devicePixelRatio()) <= width()
+       && static_cast<int>(image_.height() / qApp->devicePixelRatio()) <= height()) {
       zoomOriginal();
       return;
     }
@@ -218,6 +227,7 @@ void ImageView::zoomIn() {
     scaleFactor_ *= 1.1;
     scale(scaleFactor_, scaleFactor_);
     queueGenerateCache();
+    Q_EMIT zooming();
   }
 }
 
@@ -228,6 +238,7 @@ void ImageView::zoomOut() {
     scaleFactor_ /= 1.1;
     scale(scaleFactor_, scaleFactor_);
     queueGenerateCache();
+    Q_EMIT zooming();
   }
 }
 
@@ -238,6 +249,18 @@ void ImageView::zoomOriginal() {
   queueGenerateCache();
 }
 
+void ImageView::drawOutline() {
+  QColor col = QColor(Qt::black);
+  if (qGray(backgroundBrush().color().rgb()) < GRAY)
+    col = QColor(Qt::white);
+  QPen outline(col, 1, Qt::DashLine);
+  outline.setCosmetic(true);
+  outlineItem_->setPen(outline);
+  outlineItem_->setBrush(Qt::NoBrush);
+  outlineItem_->setVisible(showOutline_);
+  outlineItem_->setZValue(1);
+}
+
 void ImageView::setImage(const QImage& image, bool show) {
   if(show && (gifMovie_ || isSVG)) { // a gif animation or SVG file was shown before
     scene_->clear();
@@ -251,21 +274,33 @@ void ImageView::setImage(const QImage& image, bool show) {
     imageItem_->hide();
     imageItem_->setPen(QPen(Qt::NoPen));
     scene_->addItem(imageItem_);
+    // outline
+    outlineItem_ = new QGraphicsRectItem();
+    outlineItem_->hide();
+    outlineItem_->setPen(QPen(Qt::NoPen));
+    scene_->addItem(outlineItem_);
   }
 
   image_ = image;
+  QRectF r(QPointF(0, 0), image_.size() / qApp->devicePixelRatio());
   if(image.isNull()) {
     imageItem_->hide();
     imageItem_->setBrush(QBrush());
+    outlineItem_->hide();
+    outlineItem_->setBrush(QBrush());
     scene_->setSceneRect(0, 0, 0, 0);
   }
   else {
     if(show) {
-      imageItem_->setRect(0, 0, image_.width(), image_.height());
+      image_.setDevicePixelRatio(qApp->devicePixelRatio());
+      imageItem_->setRect(r);
       imageItem_->setBrush(image_);
       imageItem_->show();
+      // outline
+      outlineItem_->setRect(r);
+      drawOutline();
     }
-    scene_->setSceneRect(0, 0, image_.width(), image_.height());
+    scene_->setSceneRect(r);
   }
 
   if(autoZoomFit_)
@@ -285,6 +320,10 @@ void ImageView::setGifAnimation(const QString& fileName) {
       imageItem_->hide();
       imageItem_->setBrush(QBrush());
     }
+    if(outlineItem_) {
+      outlineItem_->hide();
+      outlineItem_->setBrush(QBrush());
+    }
     scene_->setSceneRect(0, 0, 0, 0);
   }
   else {
@@ -295,9 +334,11 @@ void ImageView::setGifAnimation(const QString& fileName) {
       gifMovie_ = nullptr;
     }
     QPixmap pix(image_.size());
+    pix.setDevicePixelRatio(qApp->devicePixelRatio());
     pix.fill(Qt::transparent);
     QGraphicsItem *gifItem = new QGraphicsPixmapItem(pix);
     QLabel *gifLabel = new QLabel();
+    gifLabel->setMaximumSize(pix.size() / qApp->devicePixelRatio()); // show gif with its real size
     gifMovie_ = new QMovie(fileName);
     QGraphicsProxyWidget* gifWidget = new QGraphicsProxyWidget(gifItem);
     gifLabel->setAttribute(Qt::WA_NoSystemBackground);
@@ -306,6 +347,12 @@ void ImageView::setGifAnimation(const QString& fileName) {
     gifMovie_->start();
     scene_->addItem(gifItem);
     scene_->setSceneRect(gifItem->boundingRect());
+
+    // outline
+    outlineItem_ = new QGraphicsRectItem(); // deleted by clear()
+    outlineItem_->setRect(gifItem->boundingRect());
+    drawOutline();
+    scene_->addItem(outlineItem_);
   }
 
   if(autoZoomFit_)
@@ -320,6 +367,10 @@ void ImageView::setSVG(const QString& fileName) {
       imageItem_->hide();
       imageItem_->setBrush(QBrush());
     }
+    if(outlineItem_) {
+      outlineItem_->hide();
+      outlineItem_->setBrush(QBrush());
+    }
     scene_->setSceneRect(0, 0, 0, 0);
   }
   else {
@@ -327,8 +378,18 @@ void ImageView::setSVG(const QString& fileName) {
     imageItem_ = nullptr;
     isSVG = true;
     QGraphicsSvgItem *svgItem = new QGraphicsSvgItem(fileName);
+    svgItem->setScale(1 / qApp->devicePixelRatio()); // show scg with its real size
     scene_->addItem(svgItem);
-    scene_->setSceneRect(svgItem->boundingRect());
+    QRectF r(svgItem->boundingRect());
+    r.setBottomRight(r.bottomRight() / qApp->devicePixelRatio());
+    r.setTopLeft(r.topLeft() / qApp->devicePixelRatio());
+    scene_->setSceneRect(r);
+
+    // outline
+    outlineItem_ = new QGraphicsRectItem(); // deleted by clear()
+    outlineItem_->setRect(r);
+    drawOutline();
+    scene_->addItem(outlineItem_);
   }
 
   if(autoZoomFit_)
@@ -345,6 +406,27 @@ void ImageView::setScaleFactor(double factor) {
   }
 }
 
+void ImageView::showOutline(bool show) {
+  if(outlineItem_) {
+    outlineItem_->setVisible(show);
+    // the viewport may not be updated automatically
+    viewport()->update();
+  }
+  showOutline_ = show;
+}
+
+void ImageView::updateOutline() {
+  if(outlineItem_) {
+    QColor col = QColor(Qt::black);
+    if (qGray(backgroundBrush().color().rgb()) < GRAY)
+      col = QColor(Qt::white);
+    QPen outline = outlineItem_->pen();
+    outline.setColor(col);
+    outlineItem_->setPen(outline);
+    viewport()->update();
+  }
+}
+
 void ImageView::paintEvent(QPaintEvent* event) {
   // if the image is scaled and we have a high quality cached image
   if(imageItem_ && scaleFactor_ != 1.0 && !cachedPixmap_.isNull()) {
@@ -361,6 +443,15 @@ void ImageView::paintEvent(QPaintEvent* event) {
         QPainter painter(viewport());
         painter.fillRect(event->rect(), backgroundBrush());
         painter.drawPixmap(repaintImageRect, cachedPixmap_);
+        // outline
+        if(showOutline_) {
+            QColor col = QColor(Qt::black);
+            if (qGray(backgroundBrush().color().rgb()) < GRAY)
+              col = QColor(Qt::white);
+            QPen outline(col, 1, Qt::DashLine);
+            painter.setPen(outline);
+            painter.drawRect(viewportImageRect);
+        }
         return;
       }
     }
@@ -424,7 +515,7 @@ void ImageView::generateCache() {
     subImage.setColorTable(colorTable);
 
   // QImage scaled = subImage.scaled(subRect.width() * scaleFactor_, subRect.height() * scaleFactor_, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-  QImage scaled = subImage.scaled(cachedRect_.width(), cachedRect_.height(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+  QImage scaled = subImage.scaled(cachedRect_.size() * qApp->devicePixelRatio(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
 
   // convert the cached scaled image to pixmap
   cachedPixmap_ = QPixmap::fromImage(scaled);
@@ -434,8 +525,10 @@ void ImageView::generateCache() {
 // convert viewport coordinate to the original image (not scaled).
 QRect ImageView::viewportToScene(const QRect& rect) {
   // QPolygon poly = mapToScene(imageItem_->rect());
-  QPoint topLeft = mapToScene(rect.topLeft()).toPoint();
-  QPoint bottomRight = mapToScene(rect.bottomRight()).toPoint();
+  /* NOTE: The scene rectangle is shrunken by qApp->devicePixelRatio()
+     but we want the coordinates with respect to the original image. */
+  QPoint topLeft = (mapToScene(rect.topLeft()) * qApp->devicePixelRatio()).toPoint();
+  QPoint bottomRight = (mapToScene(rect.bottomRight()) * qApp->devicePixelRatio()).toPoint();
   return QRect(topLeft, bottomRight);
 }
 
