@@ -38,7 +38,7 @@ class ImageView : public QGraphicsView {
   Q_OBJECT
 
 public:
-  ImageView(QWidget* parent = 0);
+  ImageView(QWidget* parent = nullptr);
   virtual ~ImageView();
 
   void setImage(const QImage& image, bool show = true);
@@ -81,9 +81,12 @@ public:
     ToolNumber
   };
   void activateTool(Tool tool);
+  void showOutline(bool show);
+  void updateOutline();
 
 Q_SIGNALS:
   void fileDropped(const QString file);
+  void zooming();
 
 protected:
   virtual void wheelEvent(QWheelEvent* event);
@@ -100,6 +103,8 @@ private:
   QRect viewportToScene(const QRect& rect);
   QRect sceneToViewport(const QRectF& rect);
 
+  void drawOutline();
+
   void drawArrow(QPainter &painter,
                  const QPoint &start,
                  const QPoint &end,
@@ -114,6 +119,7 @@ private Q_SLOTS:
 private:
   GraphicsScene* scene_; // the topmost container of all graphic items
   QGraphicsRectItem* imageItem_; // the rect item used to draw the image
+  QGraphicsRectItem* outlineItem_; // the rect to draw the image outline
   QImage image_; // image to show
   QMovie *gifMovie_; // gif animation to show (should be deleted explicitly)
   QPixmap cachedPixmap_; // caching of current viewport content (high quality scaled image)
@@ -127,6 +133,7 @@ private:
   Tool currentTool; // currently selected tool
   QPoint startPoint; // starting point for the tool
   int nextNumber;
+  bool showOutline_;
 };
 
 }
